@@ -323,7 +323,7 @@ def counting_candles(data= None, threshold = 1., contravariant = -1., lag = 2, *
     volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
-    close_diff = data.groupby(['aggregated_indice'])['close'].agg('sum')
+    close_diff = data.groupby(['aggregated_indice'])['close_diff'].agg('sum')
 
     data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
     data['aggregated_high'] =  data['aggregated_indice'].map(high)
